California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 057 - CRIMINAL SENTENCES. JUVENILE CRIMINAL PROCEEDINGS AND SENTENCING. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1378703 | CALIFORNIA CALLS ACTION FUND (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346267 | CALIFORNIA STATEWIDE LAW ENFORCEMENT ASSOCIATION ISSUES COMMITTEE (NON-PROFIT 501 (C) 5): YES ON PROPOSITION 57 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1382912 | YES ON PROP. 57, CALIFORNIANS AND GOVERNOR BROWN FOR PUBLIC SAFETY AND REHABILITATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1386627 | NO ON 57 - STOP EARLY RELEASE OF VIOLENT CRIMINALS (SERVC) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1387648 | CALIFORNIA CALLS ACTION FUND - YES ON 57 (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1384591 | MILLION VOTER PROJECT ACTION FUND - YES ON 55 AND 57, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1391170 | MILLION VOTER PROJECT ACTION FUND - YES ON 55, 56, 57, 58, 62, AND NO ON 66, SPONSORED BY SOCIAL JUSTICE ADVOCATES AND ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1391327 | OPEN PHILANTHROPY ACTION FUND YES ON 57 (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1336580 | LOS ANGELES POLICE PROTECTIVE LEAGUE ISSUES PAC - YES ON 66, NO ON 57 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385745 | FUND FOR POLICY REFORM (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1392066 | FWD.US (NONPROFIT 501(C)(4)) IN SUPPORT OF PROPOSITION 57 WITH HELP FROM CITIZENS FOR PUBLIC SAFETY AND OPPORTUNITY | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372760 | PICO CALIFORNIA - YES ON 55, 56, AND 57 (NON PROFIT 501 (C) (3)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1387575 | CIVIC PARTICIPATION ACTION FUND - YES ON 57 (NONPROFIT 501(C)(4)) | SUPPORT